@@ -11,9 +11,7 @@ try:
     from baresquare_sdk.aws import s3
     from baresquare_sdk.aws import ssm
 
-    from baresquare_sdk.core.logger import setup_logger
-
-    logger = setup_logger()
+    from baresquare_sdk.core.logger import logger
 
     __all__ = ["authentication", "s3", "ssm", "logger"]
 
