@@ -8,9 +8,7 @@ try:
 
     from baresquare_sdk.gcp import authentication, bigquery, clients, drive, pagers, sheets
 
-    from baresquare_sdk.core.logger import setup_logger
-
-    logger = setup_logger()
+    from baresquare_sdk.core.logger import logger
 
     __all__ = ["authentication", "bigquery", "clients", "drive", "pagers", "sheets", "logger"]
 
