@@ -8,6 +8,7 @@ from io import StringIO
 from unittest.mock import MagicMock, call, patch
 
 from baresquare_sdk.core.logger import (
+    DevFormatter,
     JSONFormatter,
     JSONLogger,
     get_request_context,
@@ -282,6 +283,8 @@ class TestJSONFormatter:
 
         # Assert
         assert parsed["level"] == "INFO"
+        assert parsed["severity"] == "INFO"
+        assert parsed["message"] == "Test message"
         assert parsed["env"] == "production"
         assert parsed["service"] == "test-service"
         assert parsed["file"] == "file.py"
@@ -309,6 +312,8 @@ class TestJSONFormatter:
 
         # Assert
         assert parsed["level"] == "INFO"
+        assert parsed["severity"] == "INFO"
+        assert parsed["message"] == "Test message"
         assert parsed["file"] == "file.py"
         assert "env" not in parsed
         assert "service" not in parsed
@@ -344,6 +349,8 @@ class TestJSONFormatter:
 
         # Assert
         assert parsed["level"] == "ERROR"
+        assert parsed["severity"] == "ERROR"
+        assert parsed["message"] == "Error occurred"
         assert "exception" in parsed
         assert "ValueError: Test exception" in parsed["exception"]
 
@@ -467,6 +474,116 @@ class TestJSONFormatter:
         assert isinstance(parsed["non_serializable"], str)
 
 
+class TestDevFormatter:
+    """Test suite for DevFormatter class."""
+
+    def setup_method(self):
+        """Set up test fixtures before each test method."""
+        self.formatter = DevFormatter()
+
+    def create_log_record(self, msg, level=logging.INFO, exc_info=None, extra=None):
+        """Create a log record."""
+        record = logging.LogRecord(
+            name="test_logger",
+            level=level,
+            pathname="/path/to/test_file.py",
+            lineno=123,
+            msg=msg,
+            args=(),
+            exc_info=exc_info,
+        )
+        record.filename = "test_file.py"
+        if extra:
+            record.__dict__.update(extra)
+        return record
+
+    def test_format_basic_message(self):
+        """Test formatting of a basic log message without tracebacks."""
+        # Arrange
+        record = self.create_log_record("A simple message")
+
+        # Act
+        result = self.formatter.format(record)
+
+        # Assert
+        # Don't assert timestamp, as it's brittle
+        assert result.startswith("I ")
+        assert "test_file.py        : 123 │ A simple message" in result
+        assert "\n" not in result  # No traceback should be present
+
+    def test_format_with_exc_info(self):
+        """Test formatting when exc_info is present in the log record."""
+        # Arrange
+        try:
+            raise ValueError("Test exception")
+        except ValueError:
+            exc_info = sys.exc_info()
+
+        record = self.create_log_record("An error occurred", level=logging.ERROR, exc_info=exc_info)
+
+        # Act
+        result = self.formatter.format(record)
+
+        # Assert
+        assert result.startswith("E ")
+        assert "test_file.py        : 123 │ An error occurred" in result
+        assert "\nTraceback (most recent call last):" in result
+        assert "ValueError: Test exception" in result
+
+    def test_format_with_extra_traceback(self):
+        """Test formatting when a traceback is provided in the 'extra' dict."""
+        # Arrange
+        extra_data = {"traceback": "Custom traceback string"}
+        record = self.create_log_record("Message with custom traceback", extra=extra_data)
+
+        # Act
+        result = self.formatter.format(record)
+
+        # Assert
+        assert "test_file.py        : 123 │ Message with custom traceback" in result
+        assert "\nCustom traceback string" in result
+
+    def test_format_with_extra_traceback_preferred_over_exc_info(self):
+        """Test that 'extra' traceback is preferred over exc_info."""
+        # Arrange
+        try:
+            raise ValueError("This should be ignored")
+        except ValueError:
+            exc_info = sys.exc_info()
+
+        extra_data = {"traceback": "Preferred custom traceback"}
+        record = self.create_log_record("Message", exc_info=exc_info, extra=extra_data)
+
+        # Act
+        result = self.formatter.format(record)
+
+        # Assert
+        assert "test_file.py        : 123 │ Message" in result
+        assert "\nPreferred custom traceback" in result
+        assert "ValueError: This should be ignored" not in result
+
+    @patch("baresquare_sdk.core.logger.DevFormatter.formatException")
+    def test_format_exception_formatting_fails(self, mock_format_exception):
+        """Test that formatter handles failures in formatException gracefully."""
+        # Arrange
+        mock_format_exception.side_effect = Exception("Formatting failed")
+        try:
+            raise ValueError("Test exception")
+        except ValueError:
+            exc_info = sys.exc_info()
+
+        record = self.create_log_record("An error occurred", exc_info=exc_info)
+
+        # Act
+        result = self.formatter.format(record)
+
+        # Assert
+        # Base message should still be formatted correctly
+        assert "test_file.py        : 123 │ An error occurred" in result
+        # No traceback should be appended if formatting fails
+        assert "\n" not in result
+
+
 class TestSetupLogger:
     """Test suite for setup_logger function."""
 
@@ -542,7 +659,7 @@ class TestSetupLogger:
 
         # Assert
         # Should set WARNING level for other loggers
-        expected_calls = [call("requests"), call("urllib3")]
+        expected_calls = [call()]
         mock_get_logger.assert_has_calls(expected_calls, any_order=True)
 
     def test_setup_logger_sets_json_logger_class(self):
@@ -613,6 +730,8 @@ class TestLoggerIntegration:
         parsed = json.loads(output.strip())
 
         assert parsed["level"] == "INFO"
+        assert parsed["severity"] == "INFO"
+        assert parsed["message"] == "Test message"
         assert parsed["env"] == "test"
         assert parsed["service"] == "test-service"
         assert parsed["version"] == "1.0.0"
